@@ -39,9 +39,10 @@ class TokenType(Enum):
 
 class B2Session:
     """
-        A facade that supplies the correct api_url and account_auth_token
-        to methods of underlying raw_api and reauthorizes if necessary.
+    A facade that supplies the correct api_url and account_auth_token
+    to methods of underlying raw_api and reauthorizes if necessary.
     """
+
     SQLITE_ACCOUNT_INFO_CLASS = staticmethod(SqliteAccountInfo)
     B2HTTP_CLASS = staticmethod(B2Http)
 
@@ -49,7 +50,7 @@ class B2Session:
         self,
         account_info: AbstractAccountInfo | None = None,
         cache: AbstractCache | None = None,
-        api_config: B2HttpApiConfig = DEFAULT_HTTP_API_CONFIG
+        api_config: B2HttpApiConfig = DEFAULT_HTTP_API_CONFIG,
     ):
         """
         Initialize Session using given account info.
@@ -115,7 +116,16 @@ class B2Session:
         realm_url = REALM_URLS.get(realm, realm)
         response = self.raw_api.authorize_account(realm_url, application_key_id, application_key)
         account_id = response['accountId']
-        allowed = response['allowed']
+        storage_api_info = response['apiInfo']['storageApi']
+
+        # `allowed` object has been deprecated in the v3 of the API, but we still
+        # construct it artificially to avoid changes in all the reliant parts.
+        allowed = {
+            'bucketId': storage_api_info['bucketId'],
+            'bucketName': storage_api_info['bucketName'],
+            'capabilities': storage_api_info['capabilities'],
+            'namePrefix': storage_api_info['namePrefix'],
+        }
 
         # Clear the cache if new account has been used
         if not self.account_info.is_same_account(account_id, realm):
@@ -125,13 +135,13 @@ class B2Session:
         self.account_info.set_auth_data(
             account_id=account_id,
             auth_token=response['authorizationToken'],
-            api_url=response['apiUrl'],
-            download_url=response['downloadUrl'],
-            absolute_minimum_part_size=response['absoluteMinimumPartSize'],
-            recommended_part_size=response['recommendedPartSize'],
+            api_url=storage_api_info['apiUrl'],
+            download_url=storage_api_info['downloadUrl'],
+            absolute_minimum_part_size=storage_api_info['absoluteMinimumPartSize'],
+            recommended_part_size=storage_api_info['recommendedPartSize'],
             application_key=application_key,
             realm=realm,
-            s3_api_url=response['s3ApiUrl'],
+            s3_api_url=storage_api_info['s3ApiUrl'],
             allowed=allowed,
             application_key_id=application_key_id,
         )
@@ -188,7 +198,12 @@ class B2Session:
             self.raw_api.delete_file_version, file_id, file_name, bypass_governance
         )
 
-    def download_file_from_url(self, url, range_=None, encryption: EncryptionSetting | None = None):
+    def download_file_from_url(
+        self,
+        url: str,
+        range_: tuple[int, int] | None = None,
+        encryption: EncryptionSetting | None = None,
+    ):
         return self._wrap_token(
             self.raw_api.download_file_from_url,
             TokenType.API_TOKEN_ONLY,
@@ -202,8 +217,10 @@ class B2Session:
 
     def get_download_authorization(self, bucket_id, file_name_prefix, valid_duration_in_seconds):
         return self._wrap_default_token(
-            self.raw_api.get_download_authorization, bucket_id, file_name_prefix,
-            valid_duration_in_seconds
+            self.raw_api.get_download_authorization,
+            bucket_id,
+            file_name_prefix,
+            valid_duration_in_seconds,
         )
 
     def get_file_info_by_id(self, file_id: str) -> dict[str, Any]:
@@ -454,7 +471,7 @@ class B2Session:
         callback = self._token_callbacks[token_type]
         partial_callback = partial(callback, raw_api_method, *args, **kwargs)
 
-        return self._reauthorization_loop(partial_callback)
+        return self._execute_with_auth_retry(partial_callback)
 
     def _api_token_callback(self, raw_api_method, *args, **kwargs):
         api_url = self.account_info.get_api_url()
@@ -465,20 +482,21 @@ class B2Session:
         account_auth_token = self.account_info.get_account_auth_token()
         return raw_api_method(account_auth_token, *args, **kwargs)
 
-    def _reauthorization_loop(self, callback):
-        auth_failure_encountered = False
-        while 1:
-            try:
-                return callback()
-            except InvalidAuthToken:
-                if not auth_failure_encountered:
-                    auth_failure_encountered = True
-                    reauthorization_success = self.authorize_automatically()
-                    if reauthorization_success:
-                        continue
-                raise
-            except Unauthorized as e:
-                raise self._add_app_key_info_to_unauthorized(e)
+    def _execute_with_auth_retry(self, callback, first_attempt: bool = True):
+        try:
+            return callback()
+        except InvalidAuthToken:
+            if first_attempt and self.authorize_automatically():
+                return self._execute_with_auth_retry(callback, first_attempt=False)
+            raise
+        except Unauthorized as exc:
+            # When performing HEAD requests, the api can return an empty response
+            # with a 401 status code, which may or may not be related to expired
+            # token, thus we also try to re-authorize if explicit `unauthorized`
+            # code is missing
+            if not exc.code and first_attempt and self.authorize_automatically():
+                return self._execute_with_auth_retry(callback, first_attempt=False)
+            raise self._add_app_key_info_to_unauthorized(exc)
 
     def _add_app_key_info_to_unauthorized(self, unauthorized):
         """
