@@ -16,3 +16,15 @@ import pytest
 def bg_executor():
     with concurrent.futures.ThreadPoolExecutor() as executor:
         yield executor
+
+
+@pytest.fixture
+def apiver_module():
+    """
+    b2sdk apiver module fixture.
+
+    A compatibility function that is to be replaced by `pytest-apiver` plugin in the future.
+    """
+    import apiver_deps  # noqa: F401
+
+    return apiver_deps
