@@ -43,8 +43,10 @@ class BucketCleaner:
             return False
         if bucket.name.startswith(GENERAL_BUCKET_NAME_PREFIX):
             if BUCKET_CREATED_AT_MILLIS in bucket.bucket_info:
-                if int(bucket.bucket_info[BUCKET_CREATED_AT_MILLIS]
-                      ) < current_time_millis() - ONE_HOUR_MILLIS:
+                if (
+                    int(bucket.bucket_info[BUCKET_CREATED_AT_MILLIS])
+                    < current_time_millis() - ONE_HOUR_MILLIS
+                ):
                     return True
         return False
 
@@ -76,11 +78,16 @@ class BucketCleaner:
                                 'Removing retention from file version: %s', file_version_info.id_
                             )
                             b2_api.update_file_retention(
-                                file_version_info.id_, file_version_info.file_name,
-                                NO_RETENTION_FILE_SETTING, True
+                                file_version_info.id_,
+                                file_version_info.file_name,
+                                NO_RETENTION_FILE_SETTING,
+                                True,
                             )
                         elif file_version_info.file_retention.mode == RetentionMode.COMPLIANCE:
-                            if file_version_info.file_retention.retain_until > current_time_millis():  # yapf: disable
+                            if (
+                                file_version_info.file_retention.retain_until
+                                > current_time_millis()
+                            ):
                                 logger.info(
                                     'File version: %s cannot be removed due to compliance mode retention',
                                     file_version_info.id_,
