@@ -16,7 +16,6 @@ import re
 import sys
 import time
 import traceback
-from test.helpers import type_validator_factory
 from typing import List
 
 import pytest
@@ -44,6 +43,7 @@ from b2sdk._internal.raw_api import (
 from b2sdk._internal.replication.setting import ReplicationConfiguration, ReplicationRule
 from b2sdk._internal.replication.types import ReplicationStatus
 from b2sdk._internal.utils import hex_sha1_of_stream
+from test.helpers import assert_dict_equal_ignore_extra, type_validator_factory
 
 
 # TODO: rewrite to separate test cases after introduction of reusable bucket
@@ -116,17 +116,17 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
         'writeBucketNotifications',
     }
     missing_capabilities = (
-        set(ALL_CAPABILITIES) - {'readBuckets', 'listAllBucketNames'} - preview_feature_caps -
-        set(auth_dict['allowed']['capabilities'])
-    )
-    assert not missing_capabilities, 'it appears that the raw_api integration test is being run with a non-full key. Missing capabilities: {}'.format(
-        missing_capabilities,
+        set(ALL_CAPABILITIES)
+        - {'readBuckets', 'listAllBucketNames'}
+        - preview_feature_caps
+        - set(auth_dict['apiInfo']['storageApi']['capabilities'])
     )
+    assert not missing_capabilities, f'it appears that the raw_api integration test is being run with a non-full key. Missing capabilities: {missing_capabilities}'
 
     account_id = auth_dict['accountId']
     account_auth_token = auth_dict['authorizationToken']
-    api_url = auth_dict['apiUrl']
-    download_url = auth_dict['downloadUrl']
+    api_url = auth_dict['apiInfo']['storageApi']['apiUrl']
+    download_url = auth_dict['apiInfo']['storageApi']['downloadUrl']
 
     # b2_create_key
     print('b2_create_key')
@@ -155,11 +155,13 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
     # other accounts.
     print('b2_create_bucket')
     bucket_name = 'test-raw-api-%s-%d-%d' % (
-        account_id, int(time.time()), random.randint(1000, 9999)
+        account_id,
+        int(time.time()),
+        random.randint(1000, 9999),
     )
 
     # very verbose http debug
-    #import http.client; http.client.HTTPConnection.debuglevel = 1
+    # import http.client; http.client.HTTPConnection.debuglevel = 1
 
     bucket_dict = raw_api.create_bucket(
         api_url,
@@ -197,7 +199,9 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
     try:
         # in order to test replication, we need to create a second bucket
         replication_source_bucket_name = 'test-raw-api-%s-%d-%d' % (
-            account_id, int(time.time()), random.randint(1000, 9999)
+            account_id,
+            int(time.time()),
+            random.randint(1000, 9999),
         )
         replication_source_bucket_dict = raw_api.create_bucket(
             api_url,
@@ -220,25 +224,22 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
         assert 'replicationConfiguration' in replication_source_bucket_dict
         assert replication_source_bucket_dict['replicationConfiguration'] == {
             'isClientAuthorizedToRead': True,
-            'value':
-                {
-                    "asReplicationSource":
+            'value': {
+                'asReplicationSource': {
+                    'replicationRules': [
                         {
-                            "replicationRules":
-                                [
-                                    {
-                                        "destinationBucketId": bucket_id,
-                                        "fileNamePrefix": "",
-                                        "includeExistingFiles": True,
-                                        "isEnabled": True,
-                                        "priority": 128,
-                                        "replicationRuleName": "test-rule"
-                                    },
-                                ],
-                            "sourceApplicationKeyId": replication_source_key,
+                            'destinationBucketId': bucket_id,
+                            'fileNamePrefix': '',
+                            'includeExistingFiles': True,
+                            'isEnabled': True,
+                            'priority': 128,
+                            'replicationRuleName': 'test-rule',
                         },
-                    "asReplicationDestination": None,
+                    ],
+                    'sourceApplicationKeyId': replication_source_key,
                 },
+                'asReplicationDestination': None,
+            },
         }
 
         # 3) upload test file and check replication status
@@ -259,8 +260,9 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
             io.BytesIO(file_contents),
         )
 
-        assert ReplicationStatus[file_dict['replicationStatus'].upper()
-                                ] == ReplicationStatus.PENDING
+        assert (
+            ReplicationStatus[file_dict['replicationStatus'].upper()] == ReplicationStatus.PENDING
+        )
 
     finally:
         raw_api.delete_key(api_url, account_auth_token, replication_source_key)
@@ -294,17 +296,14 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
         )
         assert bucket_dict['replicationConfiguration'] == {
             'isClientAuthorizedToRead': True,
-            'value':
-                {
-                    'asReplicationDestination':
-                        {
-                            'sourceToDestinationKeyMapping':
-                                {
-                                    replication_source_key: replication_destination_key,
-                                },
-                        },
-                    'asReplicationSource': None,
+            'value': {
+                'asReplicationDestination': {
+                    'sourceToDestinationKeyMapping': {
+                        replication_source_key: replication_destination_key,
+                    },
                 },
+                'asReplicationSource': None,
+            },
         }
     finally:
         raw_api.delete_key(
@@ -345,7 +344,7 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
     for encryption_setting, default_retention in [
         (
             sse_none,
-            BucketRetentionSetting(mode=RetentionMode.GOVERNANCE, period=RetentionPeriod(days=1))
+            BucketRetentionSetting(mode=RetentionMode.GOVERNANCE, period=RetentionPeriod(days=1)),
         ),
         (sse_b2_aes, None),
         (sse_b2_aes, BucketRetentionSetting(RetentionMode.NONE)),
@@ -363,7 +362,7 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
     # b2_list_buckets
     print('b2_list_buckets')
     bucket_list_dict = raw_api.list_buckets(api_url, account_auth_token, account_id)
-    #print(bucket_list_dict)
+    # print(bucket_list_dict)
 
     # b2_get_upload_url
     print('b2_get_upload_url')
@@ -383,17 +382,14 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
         len(file_contents),
         'text/plain',
         file_sha1,
-        {
-            'color': 'blue',
-            'b2-cache-control': 'private, max-age=2222'
-        },
+        {'color': 'blue', 'b2-cache-control': 'private, max-age=2222'},
         io.BytesIO(file_contents),
         server_side_encryption=sse_b2_aes,
-        #custom_upload_timestamp=12345,
+        # custom_upload_timestamp=12345,
         file_retention=FileRetentionSetting(
             RetentionMode.GOVERNANCE,
             int(time.time() + 100) * 1000,
-        )
+        ),
     )
 
     file_id = file_dict['fileId']
@@ -518,8 +514,12 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
     part_contents = b'hello part'
     part_sha1 = hex_sha1_of_stream(io.BytesIO(part_contents), len(part_contents))
     raw_api.upload_part(
-        upload_part_url, upload_path_auth, 1, len(part_contents), part_sha1,
-        io.BytesIO(part_contents)
+        upload_part_url,
+        upload_path_auth,
+        1,
+        len(part_contents),
+        part_sha1,
+        io.BytesIO(part_contents),
     )
 
     # b2_copy_part
@@ -599,7 +599,7 @@ def raw_api_test_helper(raw_api, should_cleanup_old_buckets):
 
 
 def _subtest_bucket_notification_rules(raw_api, auth_dict, api_url, account_auth_token, bucket_id):
-    if 'writeBucketNotifications' not in auth_dict['allowed']['capabilities']:
+    if 'writeBucketNotifications' not in auth_dict['apiInfo']['storageApi']['capabilities']:
         pytest.skip('Test account does not have writeBucketNotifications capability')
 
     notification_rule = {
@@ -607,12 +607,11 @@ def _subtest_bucket_notification_rules(raw_api, auth_dict, api_url, account_auth
         'isEnabled': False,
         'name': 'test-notification-rule',
         'objectNamePrefix': 'test/object/prefix/',
-        'targetConfiguration':
-            {
-                'targetType': 'webhook',
-                'url': 'https://example.com/webhook',
-                'hmacSha256SigningSecret': 'a' * 32,
-            },
+        'targetConfiguration': {
+            'targetType': 'webhook',
+            'url': 'https://example.com/webhook',
+            'hmacSha256SigningSecret': 'a' * 32,
+        },
     }
 
     notification_rules_response_list = raw_api.set_bucket_notification_rules(
@@ -624,17 +623,19 @@ def _subtest_bucket_notification_rules(raw_api, auth_dict, api_url, account_auth
     notification_rule_response_list_validate(notification_rules_response_list)
     expected_notification_rule_response_list = [
         {
-            **notification_rule, 'isSuspended': False,
+            **notification_rule,
+            'isSuspended': False,
             'suspensionReason': '',
-            'targetConfiguration':
-                {
-                    **notification_rule['targetConfiguration'],
-                    'customHeaders': None,
-                    'hmacSha256SigningSecret': 'a' * 32,
-                }
+            'targetConfiguration': {
+                **notification_rule['targetConfiguration'],
+                'customHeaders': None,
+                'hmacSha256SigningSecret': 'a' * 32,
+            },
         }
     ]
-    assert notification_rules_response_list == expected_notification_rule_response_list
+    assert_dict_equal_ignore_extra(
+        notification_rules_response_list, expected_notification_rule_response_list
+    )
 
     assert raw_api.set_bucket_notification_rules(api_url, account_auth_token, bucket_id, []) == []
     assert raw_api.get_bucket_notification_rules(api_url, account_auth_token, bucket_id) == []
@@ -643,8 +644,11 @@ def _subtest_bucket_notification_rules(raw_api, auth_dict, api_url, account_auth
 def cleanup_old_buckets():
     raw_api = B2RawHTTPApi(B2Http())
     auth_dict = authorize_raw_api(raw_api)
+
     bucket_list_dict = raw_api.list_buckets(
-        auth_dict['apiUrl'], auth_dict['authorizationToken'], auth_dict['accountId']
+        auth_dict['apiInfo']['storageApi']['apiUrl'],
+        auth_dict['authorizationToken'],
+        auth_dict['accountId'],
     )
     _cleanup_old_buckets(raw_api, auth_dict, bucket_list_dict)
 
@@ -657,7 +661,7 @@ def _cleanup_old_buckets(raw_api, auth_dict, bucket_list_dict):
             print('cleaning up old bucket: ' + bucket_name)
             _clean_and_delete_bucket(
                 raw_api,
-                auth_dict['apiUrl'],
+                auth_dict['apiInfo']['storageApi']['apiUrl'],
                 auth_dict['authorizationToken'],
                 auth_dict['accountId'],
                 bucket_id,
@@ -674,15 +678,18 @@ def _clean_and_delete_bucket(raw_api, api_url, account_auth_token, account_id, b
         action = version_dict['action']
         if action in ['hide', 'upload']:
             print('b2_delete_file', file_name, action)
-            if action == 'upload' and version_dict[
-                'fileRetention'] and version_dict['fileRetention']['value']['mode'] is not None:
+            if (
+                action == 'upload'
+                and version_dict['fileRetention']
+                and version_dict['fileRetention']['value']['mode'] is not None
+            ):
                 raw_api.update_file_retention(
                     api_url,
                     account_auth_token,
                     file_id,
                     file_name,
                     NO_RETENTION_FILE_SETTING,
-                    bypass_governance=True
+                    bypass_governance=True,
                 )
             raw_api.delete_file_version(api_url, account_auth_token, file_id, file_name)
         else:
