@@ -7,6 +7,7 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
 from glob import glob
 from itertools import islice
@@ -22,6 +23,6 @@ def test_files_headers():
             )  # glob('**/*.py') on Windows returns "b2\bucket.py" (wrong slash)
             head = ''.join(islice(fd, 9))
             if 'All Rights Reserved' not in head:
-                pytest.fail('Missing "All Rights Reserved" in the header in: {}'.format(file))
+                pytest.fail(f'Missing "All Rights Reserved" in the header in: {file}')
             if file not in head:
-                pytest.fail('Wrong file name in the header in: {}'.format(file))
+                pytest.fail(f'Wrong file name in the header in: {file}')
