@@ -101,7 +101,7 @@ class TestAccountInfo:
 
     @pytest.mark.parametrize(
         's3_api_url',
-        ('https://s3.us-east-123.backblazeb2.com', 'https://s3.us-west-321.backblazeb2.com')
+        ('https://s3.us-east-123.backblazeb2.com', 'https://s3.us-west-321.backblazeb2.com'),
     )
     def test_s3_api_url(self, s3_api_url):
         account_info = self.account_info_factory()
@@ -199,10 +199,12 @@ class AccountInfoBase(metaclass=ABCMeta):
             capabilities=['readFiles'],
             namePrefix=None,
         )
-        account_info.set_auth_data(**{
-            **account_info_default_data,
-            'allowed': allowed,
-        })
+        account_info.set_auth_data(
+            **{
+                **account_info_default_data,
+                'allowed': allowed,
+            }
+        )
         assert allowed == account_info.get_allowed()
 
     def test_clear_bucket_upload_data(self):
@@ -234,10 +236,12 @@ class AccountInfoBase(metaclass=ABCMeta):
         assert 'bucket-0' == account_info.get_bucket_id_or_none_from_bucket_name('my-bucket')
         assert 'my-bucket' == account_info.get_bucket_name_or_none_from_bucket_id('bucket-0')
         if self.PERSISTENCE:
-            assert 'bucket-0' == self._make_info(
-            ).get_bucket_id_or_none_from_bucket_name('my-bucket')
-            assert 'my-bucket' == self._make_info(
-            ).get_bucket_name_or_none_from_bucket_id('bucket-0')
+            assert 'bucket-0' == self._make_info().get_bucket_id_or_none_from_bucket_name(
+                'my-bucket'
+            )
+            assert 'my-bucket' == self._make_info().get_bucket_name_or_none_from_bucket_id(
+                'bucket-0'
+            )
         assert ('my-bucket', 'bucket-0') in account_info.list_bucket_names_ids()
         account_info.remove_bucket_name('my-bucket')
         assert account_info.get_bucket_id_or_none_from_bucket_name('my-bucket') is None
@@ -270,7 +274,7 @@ class AccountInfoBase(metaclass=ABCMeta):
             100,
             'app_key',
             'realm',
-            application_key_id='key_id'
+            application_key_id='key_id',
         )
 
         object_instances = [account_info]
@@ -348,7 +352,8 @@ class TestSqliteAccountInfo(AccountInfoBase):
         yield
 
         for cleanup_method in [
-            lambda: os.unlink(self.db_path), lambda: shutil.rmtree(self.test_home)
+            lambda: os.unlink(self.db_path),
+            lambda: shutil.rmtree(self.test_home),
         ]:
             try:
                 cleanup_method()
@@ -363,7 +368,9 @@ class TestSqliteAccountInfo(AccountInfoBase):
         """
         Test that a new database won't be readable by just any user
         """
-        SqliteAccountInfo(file_name=self.db_path,)
+        SqliteAccountInfo(
+            file_name=self.db_path,
+        )
         mode = os.stat(self.db_path).st_mode
         assert stat.filemode(mode) == '-rw-------'
 
@@ -379,7 +386,7 @@ class TestSqliteAccountInfo(AccountInfoBase):
 
     @pytest.mark.skipif(
         platform.system() == 'Windows',
-        reason='it fails to upgrade on Windows, not worth to fix it anymore'
+        reason='it fails to upgrade on Windows, not worth to fix it anymore',
     )
     def test_convert_from_json(self):
         """
@@ -393,7 +400,7 @@ class TestSqliteAccountInfo(AccountInfoBase):
             application_key='application_key',
             download_url='download_url',
             minimum_part_size=5000,
-            realm='production'
+            realm='production',
         )
         with open(self.db_path, 'wb') as f:
             f.write(json.dumps(data).encode('utf-8'))
