@@ -82,7 +82,7 @@ class TestApi:
         self._authorize_account()
         bucket = self.api.create_bucket('bucket1', 'allPrivate')
         created_file = bucket.upload_bytes(
-            b'hello world', 'file', cache_control="private, max-age=3600"
+            b'hello world', 'file', cache_control='private, max-age=3600'
         )
 
         result = self.api.get_file_info(created_file.id_)
@@ -103,19 +103,9 @@ class TestApi:
                     'b2-cache-control': 'private, max-age=3600',
                 },
                 'fileName': 'file',
-                'fileRetention': {
-                    'isClientAuthorizedToRead': True,
-                    'value': {
-                        'mode': None
-                    }
-                },
-                'legalHold': {
-                    'isClientAuthorizedToRead': True,
-                    'value': None
-                },
-                'serverSideEncryption': {
-                    'mode': 'none'
-                },
+                'fileRetention': {'isClientAuthorizedToRead': True, 'value': {'mode': None}},
+                'legalHold': {'isClientAuthorizedToRead': True, 'value': None},
+                'serverSideEncryption': {'mode': 'none'},
                 'uploadTimestamp': 5000,
             }
         else:
@@ -135,14 +125,9 @@ class TestApi:
             'fileId': '9999',
             'fileName': 'file',
             'fileInfo': {},
-            'serverSideEncryption': {
-                'mode': 'none'
-            },
+            'serverSideEncryption': {'mode': 'none'},
             'legalHold': None,
-            'fileRetention': {
-                'mode': None,
-                'retainUntilTimestamp': None
-            },
+            'fileRetention': {'mode': None, 'retainUntilTimestamp': None},
             'size': 11,
             'uploadTimestamp': 5000,
             'contentType': 'b2/x-auto',
@@ -151,11 +136,13 @@ class TestApi:
         }
 
         if apiver_deps.V <= 1:
-            expected_result.update({
-                'accountId': None,
-                'action': 'upload',
-                'bucketId': None,
-            })
+            expected_result.update(
+                {
+                    'accountId': None,
+                    'action': 'upload',
+                    'bucketId': None,
+                }
+            )
 
         assert result.as_dict() == expected_result
 
@@ -173,14 +160,9 @@ class TestApi:
             'fileId': '9998',
             'fileName': 'hidden-file.txt',
             'fileInfo': {},
-            'serverSideEncryption': {
-                'mode': 'none'
-            },
+            'serverSideEncryption': {'mode': 'none'},
             'legalHold': None,
-            'fileRetention': {
-                'mode': None,
-                'retainUntilTimestamp': None
-            },
+            'fileRetention': {'mode': None, 'retainUntilTimestamp': None},
             'size': 0,
             'uploadTimestamp': 5001,
             'contentSha1': 'none',
@@ -188,11 +170,13 @@ class TestApi:
         }
 
         if apiver_deps.V <= 1:
-            expected_result.update({
-                'accountId': None,
-                'action': 'upload',
-                'bucketId': None,
-            })
+            expected_result.update(
+                {
+                    'accountId': None,
+                    'action': 'upload',
+                    'bucketId': None,
+                }
+            )
 
         assert result.as_dict() == expected_result
 
@@ -216,7 +200,7 @@ class TestApi:
             'file',
             encryption=encr_setting,
             legal_hold=lh_setting,
-            file_retention=retention_setting
+            file_retention=retention_setting,
         )
 
         result = self.api.get_file_info_by_name('bucket1', 'file')
@@ -241,27 +225,19 @@ class TestApi:
                     'lifecycleRules': [],
                     'options': set(),
                     'revision': 1,
-                    'defaultServerSideEncryption':
-                        {
-                            'isClientAuthorizedToRead': True,
-                            'value': {
-                                'mode': 'none'
-                            },
-                        },
-                    'fileLockConfiguration':
-                        {
-                            'isClientAuthorizedToRead': True,
-                            'value':
-                                {
-                                    'defaultRetention': {
-                                        'mode': None,
-                                        'period': None
-                                    },
-                                    'isFileLockEnabled': None
-                                }
+                    'defaultServerSideEncryption': {
+                        'isClientAuthorizedToRead': True,
+                        'value': {'mode': 'none'},
+                    },
+                    'fileLockConfiguration': {
+                        'isClientAuthorizedToRead': True,
+                        'value': {
+                            'defaultRetention': {'mode': None, 'period': None},
+                            'isFileLockEnabled': None,
                         },
+                    },
                 },
-                marks=pytest.mark.apiver(to_ver=0)
+                marks=pytest.mark.apiver(to_ver=0),
             ),
         ],
     )
@@ -285,7 +261,7 @@ class TestApi:
 
     @pytest.mark.apiver(from_ver=3)
     def test_list_buckets_from_cache(self):
-        bucket = type("bucket", (), {"name": "bucket", "id_": "ID-0"})
+        bucket = type('bucket', (), {'name': 'bucket', 'id_': 'ID-0'})
         self._authorize_account()
         self.cache.set_bucket_name_cache([bucket])
 
@@ -294,10 +270,10 @@ class TestApi:
             return [(b.name, b.id_) for b in buckets]
 
         assert list_buckets(use_cache=True) == [('bucket', 'ID-0')]
-        assert list_buckets(bucket_name="bucket", use_cache=True) == [('bucket', 'ID-0')]
-        assert list_buckets(bucket_name="bucket2", use_cache=True) == []
-        assert list_buckets(bucket_id="ID-0", use_cache=True) == [('bucket', 'ID-0')]
-        assert list_buckets(bucket_id="ID-2", use_cache=True) == []
+        assert list_buckets(bucket_name='bucket', use_cache=True) == [('bucket', 'ID-0')]
+        assert list_buckets(bucket_name='bucket2', use_cache=True) == []
+        assert list_buckets(bucket_id='ID-0', use_cache=True) == [('bucket', 'ID-0')]
+        assert list_buckets(bucket_id='ID-2', use_cache=True) == []
         assert self.api.list_buckets() == []
 
     def test_buckets_with_encryption(self):
@@ -306,8 +282,12 @@ class TestApi:
             mode=EncryptionMode.SSE_B2,
             algorithm=EncryptionAlgorithm.AES256,
         )
-        no_encryption = EncryptionSetting(mode=EncryptionMode.NONE,)
-        unknown_encryption = EncryptionSetting(mode=EncryptionMode.UNKNOWN,)
+        no_encryption = EncryptionSetting(
+            mode=EncryptionMode.NONE,
+        )
+        unknown_encryption = EncryptionSetting(
+            mode=EncryptionMode.UNKNOWN,
+        )
 
         b1 = self.api.create_bucket(
             'bucket1',
@@ -359,7 +339,9 @@ class TestApi:
             mode=EncryptionMode.SSE_B2,
             algorithm=EncryptionAlgorithm.AES256,
         )
-        no_encryption = EncryptionSetting(mode=EncryptionMode.NONE,)
+        no_encryption = EncryptionSetting(
+            mode=EncryptionMode.NONE,
+        )
         if not should_be_encrypted:
             assert bucket.default_server_side_encryption == no_encryption
         else:
@@ -528,9 +510,13 @@ class TestApi:
     @pytest.mark.apiver(to_ver=1)
     def test_provide_raw_api_v1(self):
         from apiver_deps import B2RawApi  # test for legacy name
+
         old_style_api = B2Api(raw_api=B2RawApi(B2Http(user_agent_append='test append')))
         new_style_api = B2Api(api_config=B2HttpApiConfig(user_agent_append='test append'))
-        assert old_style_api.session.raw_api.b2_http.user_agent == new_style_api.session.raw_api.b2_http.user_agent
+        assert (
+            old_style_api.session.raw_api.b2_http.user_agent
+            == new_style_api.session.raw_api.b2_http.user_agent
+        )
         with pytest.raises(InvalidArgument):
             B2Api(
                 raw_api=B2RawApi(B2Http(user_agent_append='test append')),
@@ -572,8 +558,11 @@ class TestApi:
         assert create_result.key_name == 'testkey'
         assert create_result.capabilities == ['readFiles']
         assert create_result.account_id == self.account_info.get_account_id()
-        assert (now + 100 -
-                10) * 1000 < create_result.expiration_timestamp_millis < (now + 100 + 10) * 1000
+        assert (
+            (now + 100 - 10) * 1000
+            < create_result.expiration_timestamp_millis
+            < (now + 100 + 10) * 1000
+        )
         assert create_result.bucket_id == bucket.id_
         assert create_result.name_prefix == 'name'
         # assert create_result.options == ...  TODO
@@ -600,7 +589,10 @@ class TestApi:
             assert delete_result.key_name == create_result.key_name
             assert delete_result.capabilities == create_result.capabilities
             assert delete_result.account_id == create_result.account_id
-            assert delete_result.expiration_timestamp_millis == create_result.expiration_timestamp_millis
+            assert (
+                delete_result.expiration_timestamp_millis
+                == create_result.expiration_timestamp_millis
+            )
             assert delete_result.bucket_id == create_result.bucket_id
             assert delete_result.name_prefix == create_result.name_prefix
 
@@ -621,7 +613,8 @@ class TestApi:
                 'expirationTimestamp': None,
                 'keyName': f'testkey{ind}',
                 'namePrefix': None,
-            } for ind in [
+            }
+            for ind in [
                 0,
                 1,
                 10,
@@ -691,8 +684,7 @@ class TestApi:
         created_file = bucket.upload_bytes(
             b'hello world',
             'file',
-            file_retention=FileRetentionSetting(RetentionMode.GOVERNANCE,
-                                                int(time.time()) + 100),
+            file_retention=FileRetentionSetting(RetentionMode.GOVERNANCE, int(time.time()) + 100),
         )
 
         with pytest.raises(AccessDenied):
