@@ -42,7 +42,6 @@ DEFAULT_REPLICATION_RESULT = dict(
 
 
 def test_iter_pairs(source_bucket, destination_bucket, test_file, monitor):
-
     source_file = source_bucket.upload_local_file(test_file, 'folder/test.txt')
     source_subfolder_file = source_bucket.upload_local_file(test_file, 'folder/subfolder/test.txt')
 
@@ -57,7 +56,8 @@ def test_iter_pairs(source_bucket, destination_bucket, test_file, monitor):
         (
             source_path and 'folder/' + source_path.relative_path,
             destination_path and 'folder/' + destination_path.relative_path,
-        ) for source_path, destination_path in monitor.iter_pairs()
+        )
+        for source_path, destination_path in monitor.iter_pairs()
     ]
 
     assert set(pairs) == {
@@ -73,15 +73,16 @@ def test_scan_source(source_bucket, test_file, monitor):
         source_bucket.upload_local_file(test_file, 'folder/test-1-1.txt'),
         source_bucket.upload_local_file(test_file, 'folder/test-1-2.txt'),
         source_bucket.upload_local_file(test_file, 'folder/test-2.txt', encryption=SSE_B2_AES),
-        source_bucket.upload_local_file(test_file,
-                                        'not-in-folder.txt'),  # monitor should ignore this
+        source_bucket.upload_local_file(
+            test_file, 'not-in-folder.txt'
+        ),  # monitor should ignore this
         source_bucket.upload_local_file(test_file, 'folder/test-3.txt', encryption=SSE_C_AES),
         source_bucket.upload_local_file(test_file, 'folder/test-4.txt', encryption=SSE_C_AES),
         source_bucket.upload_local_file(
             test_file,
             'folder/subfolder/test-5.txt',
             encryption=SSE_C_AES,
-            file_retention=RETENTION_GOVERNANCE
+            file_retention=RETENTION_GOVERNANCE,
         ),
         source_bucket.upload_local_file(
             test_file,
@@ -103,50 +104,87 @@ def test_scan_source(source_bucket, test_file, monitor):
 
     assert report.counter_by_status[ReplicationScanResult(**DEFAULT_REPLICATION_RESULT)] == 2
 
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'source_encryption_mode': EncryptionMode.SSE_B2,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'source_encryption_mode': EncryptionMode.SSE_B2,
+                }
+            )
+        ]
+        == 1
+    )
 
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'source_encryption_mode': EncryptionMode.SSE_C,
-        }
-    )] == 2
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'source_encryption_mode': EncryptionMode.SSE_C,
+                }
+            )
+        ]
+        == 2
+    )
 
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'source_encryption_mode': EncryptionMode.SSE_C,
-            'source_has_file_retention': True,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'source_encryption_mode': EncryptionMode.SSE_C,
+                    'source_has_file_retention': True,
+                }
+            )
+        ]
+        == 1
+    )
 
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'source_has_large_metadata': True,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'source_has_large_metadata': True,
+                }
+            )
+        ]
+        == 1
+    )
 
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'source_encryption_mode': EncryptionMode.SSE_C,
-            'source_has_large_metadata': True,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'source_encryption_mode': EncryptionMode.SSE_C,
+                    'source_has_large_metadata': True,
+                }
+            )
+        ]
+        == 1
+    )
 
     # ---- first and last ----
 
-    assert report.samples_by_status_first[ReplicationScanResult(**DEFAULT_REPLICATION_RESULT,)
-                                         ][0] == files[0]
+    assert (
+        report.samples_by_status_first[
+            ReplicationScanResult(
+                **DEFAULT_REPLICATION_RESULT,
+            )
+        ][0]
+        == files[0]
+    )
 
-    assert report.samples_by_status_last[ReplicationScanResult(**DEFAULT_REPLICATION_RESULT,)
-                                        ][0] == files[1]
+    assert (
+        report.samples_by_status_last[
+            ReplicationScanResult(
+                **DEFAULT_REPLICATION_RESULT,
+            )
+        ][0]
+        == files[1]
+    )
 
 
 def test_scan_source_and_destination(
@@ -156,25 +194,25 @@ def test_scan_source_and_destination(
         # match
         source_bucket.upload_local_file(test_file, 'folder/test-1.txt'),
         destination_bucket.upload_local_file(test_file, 'folder/test-1.txt'),
-
         # missing on destination
         source_bucket.upload_local_file(test_file, 'folder/test-2.txt'),
-
         # missing on source
         destination_bucket.upload_local_file(test_file, 'folder/test-3.txt'),
-
         # metadata differs
         source_bucket.upload_local_file(
-            test_file, 'folder/test-4.txt', file_info={
+            test_file,
+            'folder/test-4.txt',
+            file_info={
                 'haha': 'hoho',
-            }
+            },
         ),
         destination_bucket.upload_local_file(
-            test_file, 'folder/test-4.txt', file_info={
+            test_file,
+            'folder/test-4.txt',
+            file_info={
                 'hehe': 'hihi',
-            }
+            },
         ),
-
         # hash differs
         source_bucket.upload_local_file(test_file, 'folder/test-5.txt'),
         destination_bucket.upload_local_file(test_file_reversed, 'folder/test-5.txt'),
@@ -183,49 +221,74 @@ def test_scan_source_and_destination(
     report = monitor.scan(scan_destination=True)
 
     # match
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'metadata_differs': False,
-            'hash_differs': False,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'metadata_differs': False,
+                    'hash_differs': False,
+                }
+            )
+        ]
+        == 1
+    )
 
     # missing on destination
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'destination_replication_status': None,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'destination_replication_status': None,
+                }
+            )
+        ]
+        == 1
+    )
 
     # missing on source
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'source_replication_status': None,
-            'source_has_hide_marker': None,
-            'source_encryption_mode': None,
-            'source_has_large_metadata': None,
-            'source_has_file_retention': None,
-            'source_has_legal_hold': None,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'source_replication_status': None,
+                    'source_has_hide_marker': None,
+                    'source_encryption_mode': None,
+                    'source_has_large_metadata': None,
+                    'source_has_file_retention': None,
+                    'source_has_legal_hold': None,
+                }
+            )
+        ]
+        == 1
+    )
 
     # metadata differs
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'metadata_differs': True,
-            'hash_differs': False,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'metadata_differs': True,
+                    'hash_differs': False,
+                }
+            )
+        ]
+        == 1
+    )
 
     # hash differs
-    assert report.counter_by_status[ReplicationScanResult(
-        **{
-            **DEFAULT_REPLICATION_RESULT,
-            'metadata_differs': False,
-            'hash_differs': True,
-        }
-    )] == 1
+    assert (
+        report.counter_by_status[
+            ReplicationScanResult(
+                **{
+                    **DEFAULT_REPLICATION_RESULT,
+                    'metadata_differs': False,
+                    'hash_differs': True,
+                }
+            )
+        ]
+        == 1
+    )
