@@ -7,12 +7,12 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
+
 import pathlib
 
-import pytest
-
-from b2sdk import requests
-from b2sdk.requests.included_source_meta import included_source_meta
+from b2sdk._internal import requests
+from b2sdk._internal.requests.included_source_meta import included_source_meta
 
 
 def test_requests_notice_file():
