@@ -7,5 +7,6 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
-from b2sdk.v0.exception import *
+from b2sdk.v0.exception import *  # noqa
