@@ -39,7 +39,11 @@ class TestCopyManager(TestBase):
     def test_establish_sse_c_replace(self):
         file_info = {'some_key': 'some_value'}
         content_type = 'text/plain'
-        metadata_directive, new_file_info, new_content_type = CopyManager.establish_sse_c_file_metadata(
+        (
+            metadata_directive,
+            new_file_info,
+            new_content_type,
+        ) = CopyManager.establish_sse_c_file_metadata(
             MetadataDirectiveMode.REPLACE,
             destination_file_info=file_info,
             destination_content_type=content_type,
@@ -50,17 +54,21 @@ class TestCopyManager(TestBase):
         )
         self.assertEqual(
             (
-                MetadataDirectiveMode.REPLACE, {
-                    'some_key': 'some_value',
-                    SSE_C_KEY_ID_FILE_INFO_KEY_NAME: 'some-id'
-                }, content_type
-            ), (metadata_directive, new_file_info, new_content_type)
+                MetadataDirectiveMode.REPLACE,
+                {'some_key': 'some_value', SSE_C_KEY_ID_FILE_INFO_KEY_NAME: 'some-id'},
+                content_type,
+            ),
+            (metadata_directive, new_file_info, new_content_type),
         )
 
     def test_establish_sse_c_copy_no_enc(self):
         file_info = {}
         content_type = 'text/plain'
-        metadata_directive, new_file_info, new_content_type = CopyManager.establish_sse_c_file_metadata(
+        (
+            metadata_directive,
+            new_file_info,
+            new_content_type,
+        ) = CopyManager.establish_sse_c_file_metadata(
             MetadataDirectiveMode.COPY,
             destination_file_info=file_info,
             destination_content_type=content_type,
@@ -71,13 +79,17 @@ class TestCopyManager(TestBase):
         )
         self.assertEqual(
             (MetadataDirectiveMode.COPY, {}, content_type),
-            (metadata_directive, new_file_info, new_content_type)
+            (metadata_directive, new_file_info, new_content_type),
         )
 
     def test_establish_sse_c_copy_b2(self):
         file_info = {}
         content_type = 'text/plain'
-        metadata_directive, new_file_info, new_content_type = CopyManager.establish_sse_c_file_metadata(
+        (
+            metadata_directive,
+            new_file_info,
+            new_content_type,
+        ) = CopyManager.establish_sse_c_file_metadata(
             MetadataDirectiveMode.COPY,
             destination_file_info=file_info,
             destination_content_type=content_type,
@@ -88,13 +100,17 @@ class TestCopyManager(TestBase):
         )
         self.assertEqual(
             (MetadataDirectiveMode.COPY, {}, content_type),
-            (metadata_directive, new_file_info, new_content_type)
+            (metadata_directive, new_file_info, new_content_type),
         )
 
     def test_establish_sse_c_copy_same_key_id(self):
         file_info = None
         content_type = 'text/plain'
-        metadata_directive, new_file_info, new_content_type = CopyManager.establish_sse_c_file_metadata(
+        (
+            metadata_directive,
+            new_file_info,
+            new_content_type,
+        ) = CopyManager.establish_sse_c_file_metadata(
             MetadataDirectiveMode.COPY,
             destination_file_info=file_info,
             destination_content_type=content_type,
@@ -105,11 +121,15 @@ class TestCopyManager(TestBase):
         )
         self.assertEqual(
             (MetadataDirectiveMode.COPY, None, content_type),
-            (metadata_directive, new_file_info, new_content_type)
+            (metadata_directive, new_file_info, new_content_type),
         )
 
     def test_establish_sse_c_copy_sources_given(self):
-        metadata_directive, new_file_info, new_content_type = CopyManager.establish_sse_c_file_metadata(
+        (
+            metadata_directive,
+            new_file_info,
+            new_content_type,
+        ) = CopyManager.establish_sse_c_file_metadata(
             MetadataDirectiveMode.COPY,
             destination_file_info=None,
             destination_content_type=None,
@@ -117,25 +137,23 @@ class TestCopyManager(TestBase):
             source_server_side_encryption=SSE_C_AES_2,
             source_file_info={
                 'some_key': 'some_value',
-                SSE_C_KEY_ID_FILE_INFO_KEY_NAME: 'some-id-2'
+                SSE_C_KEY_ID_FILE_INFO_KEY_NAME: 'some-id-2',
             },
             source_content_type='text/plain',
         )
         self.assertEqual(
             (
-                MetadataDirectiveMode.REPLACE, {
-                    'some_key': 'some_value',
-                    SSE_C_KEY_ID_FILE_INFO_KEY_NAME: 'some-id'
-                }, 'text/plain'
-            ), (metadata_directive, new_file_info, new_content_type)
+                MetadataDirectiveMode.REPLACE,
+                {'some_key': 'some_value', SSE_C_KEY_ID_FILE_INFO_KEY_NAME: 'some-id'},
+                'text/plain',
+            ),
+            (metadata_directive, new_file_info, new_content_type),
         )
 
     def test_establish_sse_c_copy_sources_unknown(self):
         for source_file_info, source_content_type in [
             (None, None),
-            ({
-                'a': 'b'
-            }, None),
+            ({'a': 'b'}, None),
             (None, 'text/plain'),
         ]:
             with self.subTest(
@@ -144,7 +162,7 @@ class TestCopyManager(TestBase):
                 with self.assertRaises(
                     SSECKeyIdMismatchInCopy,
                     'attempting to copy file using MetadataDirectiveMode.COPY without providing source_file_info '
-                    'and source_content_type for differing sse_c_key_ids: source="some-id-2", destination="some-id"'
+                    'and source_content_type for differing sse_c_key_ids: source="some-id-2", destination="some-id"',
                 ):
                     CopyManager.establish_sse_c_file_metadata(
                         MetadataDirectiveMode.COPY,
